==> h3dapi-2.3.0.tar.gz: h3dapi-2.3.0/src/TimeTrigger.cpp <==
//////////////////////////////////////////////////////////////////////////////
//    Copyright 2004-2014, SenseGraphics AB
//
//    This file is part of H3D API.
//
//    H3D API is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    H3D API is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with H3D API; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//    A commercial license is also available. Please contact us at 
//    www.sensegraphics.com for more information.
//
//
/// \file TimeTrigger.cpp
/// \brief CPP file for TimeTrigger, X3D scene-graph node
///
//
//
//////////////////////////////////////////////////////////////////////////////

#include <H3D/TimeTrigger.h>

using namespace H3D;

// Add this node to the H3DNodeDatabase system.
H3DNodeDatabase TimeTrigger::database( 
                                   "TimeTrigger", 
                                   &(newInstance<TimeTrigger>), 
                                   typeid( TimeTrigger ),
                                   &X3DTriggerNode::database );

namespace TimeTriggerInternals {
  FIELDDB_ELEMENT( TimeTrigger, set_boolean, INPUT_ONLY );
  FIELDDB_ELEMENT( TimeTrigger, triggerTime, OUTPUT_ONLY );
}

TimeTrigger::TimeTrigger( Inst< SFNode         > _metadata,
                          Inst< SFBool         > _set_boolean,
                          Inst< SetTriggerTime > _triggerTime ):
  X3DTriggerNode( _metadata     ),
  set_boolean   ( _set_boolean  ),
  triggerTime   ( _triggerTime  ){

  type_name = "TimeTrigger";
  database.initFields( this );

  set_boolean->route( triggerTime, id );
}

==> h3dapi-2.4.0.tar.gz: h3dapi-2.4.0/src/TimeTrigger.cpp <==
//////////////////////////////////////////////////////////////////////////////
//    Copyright 2004-2019, SenseGraphics AB
//
//    This file is part of H3D API.
//
//    H3D API is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    H3D API is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with H3D API; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//    A commercial license is also available. Please contact us at 
//    www.sensegraphics.com for more information.
//
//
/// \file TimeTrigger.cpp
/// \brief CPP file for TimeTrigger, X3D scene-graph node
///
//
//
//////////////////////////////////////////////////////////////////////////////

#include <H3D/TimeTrigger.h>

using namespace H3D;

// Add this node to the H3DNodeDatabase system.
H3DNodeDatabase TimeTrigger::database( 
                                   "TimeTrigger", 
                                   &(newInstance<TimeTrigger>), 
                                   typeid( TimeTrigger ),
                                   &X3DTriggerNode::database );

namespace TimeTriggerInternals {
  FIELDDB_ELEMENT( TimeTrigger, set_boolean, INPUT_ONLY )
  FIELDDB_ELEMENT( TimeTrigger, triggerTime, OUTPUT_ONLY )
}

TimeTrigger::TimeTrigger( Inst< SFNode         > _metadata,
                          Inst< SFBool         > _set_boolean,
                          Inst< SetTriggerTime > _triggerTime ):
  X3DTriggerNode( _metadata     ),
  set_boolean   ( _set_boolean  ),
  triggerTime   ( _triggerTime  ){

  type_name = "TimeTrigger";
  database.initFields( this );

  set_boolean->route( triggerTime, id );
}
